@@ -38,6 +38,7 @@
 #include "glade-cursor.h"
 #include "glade-catalog.h"
 #include "glade-fixed.h"
+#include "glade-design-view.h"
 #include "glade-marshallers.h"
 #include "glade-accumulators.h"
 
@@ -46,7 +47,7 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtkstock.h>
+#include <gtk/gtk.h>
 
 #define GLADE_CONFIG_FILENAME "glade-3.conf"
 
@@ -252,13 +253,9 @@ glade_app_refresh_undo_redo_button (GladeApp *app,
 				    gboolean undo)
 {
 	GladeCommand *command = NULL;
-	static GtkTooltips *button_tips = NULL;
 	GladeProject *project;
 	gchar *desc;
 
-	if (button_tips == NULL)
-		button_tips = gtk_tooltips_new ();
-	
 	if ((project = glade_app_get_project ()) != NULL)
 	{
 		if (undo)
@@ -270,7 +267,7 @@ glade_app_refresh_undo_redo_button (GladeApp *app,
 	/* Change tooltips */
 	desc = g_strdup_printf ((undo) ? _("Undo: %s") : _("Redo: %s"),
 			command ? command->description : _("the last action"));
-	gtk_tooltips_set_tip (GTK_TOOLTIPS (button_tips), button, desc, NULL);
+        gtk_widget_set_tooltip_text (button, desc);
 	g_free (desc);
 
 	/* Set sensitivity on the button */
@@ -291,31 +288,6 @@ glade_app_update_ui_default (GladeApp *app)
 			glade_app_refresh_undo_redo_button (app, list->data, FALSE);
 }
 
-static void
-on_palette_button_clicked (GladePalette *palette, GladeApp *app)
-{
-	GladeWidgetAdaptor *adaptor;
-	GladeWidget        *widget;
-
-	g_return_if_fail (GLADE_IS_PALETTE (palette));
-	adaptor = glade_palette_get_current_item (palette);
-
-	/* class may be NULL if the selector was pressed */
-	if (adaptor && GWA_IS_TOPLEVEL (adaptor))
-	{
-		widget = glade_command_create (adaptor, NULL, NULL, app->priv->active_project);
-		
-		/* if this is a top level widget set the accel group */
-		if (widget && app->priv->accel_group && GTK_IS_WINDOW (widget->object))
-		{
-			gtk_window_add_accel_group (GTK_WINDOW (widget->object),
-						    app->priv->accel_group);
-		}
-
-		glade_palette_deselect_current_item (palette, FALSE);
-	}
-}
-
 static gboolean
 clipboard_view_on_delete_cb (GtkWidget *clipboard_view, GdkEvent *e, GladeApp *app)
 {
@@ -386,7 +358,7 @@ build_package_paths (void)
 #ifdef G_OS_WIN32
 	gchar *prefix;
 	
-	prefix = g_win32_get_package_installation_directory (NULL, NULL);
+	prefix = g_win32_get_package_installation_directory_of_module (NULL);
 	pixmaps_dir  = g_build_filename (prefix, "share", PACKAGE, "pixmaps", NULL);
 	catalogs_dir = g_build_filename (prefix, "share", PACKAGE, "catalogs", NULL);
 	modules_dir  = g_build_filename (prefix, "lib", PACKAGE, "modules", NULL);
@@ -446,9 +418,6 @@ glade_app_init (GladeApp *app)
 	app->priv->palette = (GladePalette *) glade_palette_new (app->priv->catalogs);
 	g_object_ref_sink (app->priv->palette);
 	
-	g_signal_connect (G_OBJECT (app->priv->palette), "toggled",
-			  G_CALLBACK (on_palette_button_clicked), app);
-
 	/* Create Editor */
 	app->priv->editor = GLADE_EDITOR (glade_editor_new ());
 	g_object_ref_sink (GTK_OBJECT (app->priv->editor));
@@ -525,14 +494,6 @@ glade_app_class_init (GladeAppClass * klass)
 /*****************************************************************
  *                       Public API                              *
  *****************************************************************/
-static void
-on_widget_name_changed_cb (GladeProject *project,
-			   GladeWidget *widget,
-			   GladeEditor *editor)
-{
-	glade_editor_update_widget_name (editor);
-}
-
 static void
 on_project_selection_changed_cb (GladeProject *project, GladeApp *app)
 {
@@ -552,8 +513,7 @@ on_project_selection_changed_cb (GladeProject *project, GladeApp *app)
 		num = g_list_length (list);
 		if (num == 1 && !GLADE_IS_PLACEHOLDER (list->data))
 			glade_editor_load_widget (app->priv->editor,
-						  glade_widget_get_from_gobject
-						  (G_OBJECT (list->data)));
+						  glade_widget_get_from_gobject (list->data));
 		else
 			glade_editor_load_widget (app->priv->editor, NULL);
 	}
@@ -592,7 +552,7 @@ glade_app_config_save ()
 			/* Config dir exists but is not a directory */
 			glade_util_ui_message
 				(glade_app_get_window(),
-				 GLADE_UI_ERROR,
+				 GLADE_UI_ERROR, NULL,
 				 _("Trying to save private data to %s directory "
 				   "but it is a regular file.\n"
 				   "No private data will be saved in this session"), 
@@ -605,7 +565,7 @@ glade_app_config_save ()
 			/* Doesnt exist; failed to create */
 			glade_util_ui_message
 				(glade_app_get_window(),
-				 GLADE_UI_ERROR,
+				 GLADE_UI_ERROR, NULL,
 				 _("Failed to create directory %s to save private data.\n"
 				   "No private data will be saved in this session"), config_dir);
 			error_shown = TRUE;
@@ -633,7 +593,7 @@ glade_app_config_save ()
 			{
 				glade_util_ui_message
 					(glade_app_get_window(),
-					 GLADE_UI_ERROR,
+					 GLADE_UI_ERROR, NULL,
 					 _("Error writing private data to %s (%s).\n"
 					   "No private data will be saved in this session"), 
 					 filename, error->message);
@@ -645,7 +605,7 @@ glade_app_config_save ()
 		{
 			glade_util_ui_message
 				(glade_app_get_window(),
-				 GLADE_UI_ERROR,
+				 GLADE_UI_ERROR, NULL,
 				 _("Error serializing configuration data to save (%s).\n"
 				   "No private data will be saved in this session"), 
 				 error->message);
@@ -658,7 +618,7 @@ glade_app_config_save ()
 	{
 		glade_util_ui_message
 			(glade_app_get_window(),
-			 GLADE_UI_ERROR,
+			 GLADE_UI_ERROR, NULL,
 			 _("Error opening %s to write private data (%s).\n"
 			   "No private data will be saved in this session"), 
 			 filename, error->message);
@@ -732,6 +692,48 @@ glade_app_set_window (GtkWidget *window)
 	app->priv->window = window;
 }
 
+GladeCatalog *
+glade_app_get_catalog (const gchar *name)
+{
+	GladeApp     *app = glade_app_get ();
+	GList        *list;
+	GladeCatalog *catalog;
+
+	g_return_val_if_fail (name && name[0], NULL);
+
+	for (list = app->priv->catalogs; list; list = list->next)
+	{
+		catalog = list->data;
+		if (!strcmp (glade_catalog_get_name (catalog), name))
+			return catalog;
+	}
+	return NULL;
+}
+
+gboolean
+glade_app_get_catalog_version (const gchar *name, gint *major, gint *minor)
+{
+	GladeCatalog *catalog = glade_app_get_catalog (name);
+
+	g_return_val_if_fail (catalog != NULL, FALSE);
+
+	if (major)
+		*major = glade_catalog_get_major_version (catalog);
+	if (minor)
+		*minor = glade_catalog_get_minor_version (catalog);
+	
+	return TRUE;
+}
+
+GList *
+glade_app_get_catalogs (void)
+{
+	GladeApp *app = glade_app_get ();
+
+	return app->priv->catalogs; 
+}
+
+
 GtkWidget *
 glade_app_get_window (void)
 {
@@ -774,6 +776,14 @@ glade_app_get_project (void)
 	return app->priv->active_project;
 }
 
+GladeProject *
+glade_app_check_get_project (void)
+{
+	if (singleton_app)
+		return glade_app_get_project ();
+	return NULL;
+}
+
 GList *
 glade_app_get_projects (void)
 {
@@ -857,7 +867,7 @@ glade_app_show_properties (gboolean raise)
 	if (GLADE_APP_GET_CLASS (app)->show_properties)
 		GLADE_APP_GET_CLASS (app)->show_properties (app, raise);
 	else 
-		g_critical ("%s not implemented\n", G_GNUC_FUNCTION);
+		g_critical ("%s not implemented\n", G_STRFUNC);
 }
 
 void
@@ -868,7 +878,7 @@ glade_app_hide_properties (void)
 	if (GLADE_APP_GET_CLASS (app)->hide_properties)
 		GLADE_APP_GET_CLASS (app)->hide_properties (app);
 	else 
-		g_critical ("%s not implemented\n", G_GNUC_FUNCTION);
+		g_critical ("%s not implemented\n", G_STRFUNC);
 
 }
 
@@ -920,34 +930,54 @@ void
 glade_app_add_project (GladeProject *project)
 {
 	GladeApp  *app;
+	GladeDesignView *view;
+	GladeDesignLayout *layout;
+
  	g_return_if_fail (GLADE_IS_PROJECT (project));
 
+	app = glade_app_get ();
+
 	/* If the project was previously loaded, don't re-load */
-	if (glade_app_is_project_loaded (glade_project_get_path (project)))
+	if (g_list_find (app->priv->projects, project) != NULL)
 	{
 		glade_app_set_project (project);
 		return;
 	}
 	glade_app_update_instance_count (project);
-
-	app = glade_app_get ();
 	
-	g_object_ref (project);
-	
-	app->priv->projects = g_list_append (app->priv->projects, project);
+	/* Take a reference for GladeApp here... */
+	app->priv->projects = g_list_append (app->priv->projects, 
+					     g_object_ref (project));
 	
 	/* connect to the project signals so that the editor can be updated */
-	g_signal_connect (G_OBJECT (project), "widget_name_changed",
-			  G_CALLBACK (on_widget_name_changed_cb), app->priv->editor);
 	g_signal_connect (G_OBJECT (project), "selection_changed",
 			  G_CALLBACK (on_project_selection_changed_cb), app);
 
-	/* add acceleration groups to every top level widget */
-	if (app->priv->accel_group)
-		glade_project_set_accel_group (project, app->priv->accel_group);
 	
 	glade_app_set_project (project);
 
+	/* Select the first window in the project */
+	if (g_list_length (app->priv->projects) == 1 ||
+	    !(view = glade_design_view_get_from_project (project)) ||
+	    !(layout = glade_design_view_get_layout (view)) ||
+	    !GTK_BIN (layout)->child)
+	{
+		const GList *node;
+		for (node = glade_project_get_objects (project);
+		     node != NULL;
+		     node = g_list_next (node))
+		{
+			GObject *obj = G_OBJECT (node->data);
+
+			if (GTK_IS_WINDOW (obj))
+			{
+				glade_project_selection_set (project, obj, TRUE);
+				glade_widget_show (glade_widget_get_from_gobject (obj));
+				break;
+			}
+		}
+	}
+
 	/* XXX I think the palette & editor should detect this by itself */
 	gtk_widget_set_sensitive (GTK_WIDGET (app->priv->palette), TRUE);
 	gtk_widget_set_sensitive (GTK_WIDGET (app->priv->editor), TRUE);
@@ -988,7 +1018,6 @@ glade_app_remove_project (GladeProject *project)
 	 * that point.
 	 */
 	g_object_unref (project);
-
 }
 
 
@@ -1024,6 +1053,9 @@ glade_app_set_project (GladeProject *project)
 	/* (XXX really ?) trigger the selection changed signal to update the editor */
 	glade_project_selection_changed (project);
 	
+	/* refresh palette for active project */
+	glade_palette_refresh (glade_app_get_palette ());
+
 	/* Update UI */
 	glade_app_update_ui ();
 
@@ -1088,20 +1120,8 @@ glade_app_command_copy (void)
 	for (list = glade_app_get_selection ();
 	     list && list->data; list = list->next)
 	{
-		widget  = glade_widget_get_from_gobject (GTK_WIDGET (list->data));
+		widget  = glade_widget_get_from_gobject (list->data);
 		widgets = g_list_prepend (widgets, widget);
-		
-		g_assert (widget);
-		if (widget->internal)
-		{
-			glade_util_ui_message
-				(glade_app_get_window(),
-				 GLADE_UI_WARN,
-				 _("You cannot copy a widget "
-				   "internal to a composite widget."));
-			failed = TRUE;
-			break;
-		}
 	}
 
 	if (failed == FALSE && widgets != NULL)
@@ -1111,7 +1131,7 @@ glade_app_command_copy (void)
 	}
 	else if (widgets == NULL)
 		glade_util_ui_message (glade_app_get_window(),
-				       GLADE_UI_INFO,
+				       GLADE_UI_INFO, NULL,
 				       _("No widget selected."));
 
 	if (widgets) g_list_free (widgets);
@@ -1141,20 +1161,8 @@ glade_app_command_cut (void)
 	for (list = glade_app_get_selection ();
 	     list && list->data; list = list->next)
 	{
-		widget  = glade_widget_get_from_gobject (GTK_WIDGET (list->data));
+		widget  = glade_widget_get_from_gobject (list->data);
 		widgets = g_list_prepend (widgets, widget);
-		
-		g_assert (widget);
-		if (widget->internal)
-		{
-			glade_util_ui_message
-				(glade_app_get_window(),
-				 GLADE_UI_WARN,
-				 _("You cannot cut a widget "
-				   "internal to a composite widget."));
-			failed = TRUE;
-			break;
-		}
 	}
 
 	if (failed == FALSE && widgets != NULL)
@@ -1164,7 +1172,7 @@ glade_app_command_cut (void)
 	}
 	else if (widgets == NULL)
 		glade_util_ui_message (glade_app_get_window(),
-				       GLADE_UI_INFO,
+				       GLADE_UI_INFO, NULL,
 				       _("No widget selected."));
 
 	if (widgets) g_list_free (widgets);
@@ -1196,11 +1204,19 @@ glade_app_command_paste (GladePlaceholder *placeholder)
 	clipboard = glade_app_get_clipboard ();
 
 	/* If there is a selection, paste in to the selected widget, otherwise
-	 * paste into the placeholder's parent.
+	 * paste into the placeholder's parent, or at the toplevel
 	 */
 	parent = list ? glade_widget_get_from_gobject (list->data) : 
 		 (placeholder) ? glade_placeholder_get_parent (placeholder) : NULL;
-	
+
+	widget = clipboard->selection ? clipboard->selection->data : NULL;
+
+	/* Ignore parent argument if we are pasting a toplevel
+	 */
+	if (g_list_length (clipboard->selection) == 1 &&
+	    widget && GWA_IS_TOPLEVEL (widget->adaptor))
+		parent = NULL;
+
 	if (parent && GLADE_IS_FIXED (parent)) fixed = GLADE_FIXED (parent);
 
 	/* Check if parent is actually a container of any sort */
@@ -1208,7 +1224,7 @@ glade_app_command_paste (GladePlaceholder *placeholder)
 	    !glade_widget_adaptor_is_container (parent->adaptor))
 	{
 		glade_util_ui_message (glade_app_get_window(),
-				       GLADE_UI_INFO,
+				       GLADE_UI_INFO, NULL,
 				       _("Unable to paste to the selected parent"));
 		return;
 	}
@@ -1219,7 +1235,7 @@ glade_app_command_paste (GladePlaceholder *placeholder)
 		if (g_list_length (list) != 1)
 		{
 			glade_util_ui_message (glade_app_get_window(),
-					       GLADE_UI_INFO,
+					       GLADE_UI_INFO, NULL,
 					       _("Unable to paste to multiple widgets"));
 
 			return;
@@ -1229,7 +1245,7 @@ glade_app_command_paste (GladePlaceholder *placeholder)
 	/* Check if we have anything to paste */
 	if (g_list_length (clipboard->selection) == 0)
 	{
-		glade_util_ui_message (glade_app_get_window (), GLADE_UI_INFO,
+		glade_util_ui_message (glade_app_get_window (), GLADE_UI_INFO, NULL,
 				    _("No widget selected on the clipboard"));
 
 		return;
@@ -1248,18 +1264,6 @@ glade_app_command_paste (GladePlaceholder *placeholder)
 			if (glade_widget_placeholder_relation (parent, widget))
 				placeholder_relations++;
 		}
-
-		/* Check if there is no parent and at least on of the pasted
-		 * widgets is not a toplevel 
-		 */
-		else if (!GWA_IS_TOPLEVEL (widget->adaptor) && !parent)
-		{
-			glade_util_ui_message (glade_app_get_window (),
-					       GLADE_UI_INFO, 
-					       _("Unable to paste widget %s without a parent"),
-					       widget->name);
-			return;
-		}
 	}
 
 	g_assert (widget);
@@ -1267,12 +1271,13 @@ glade_app_command_paste (GladePlaceholder *placeholder)
 	/* A GladeFixed that doesnt use placeholders can only paste one
 	 * at a time
  	 */
-	if (GTK_WIDGET_TOPLEVEL (widget->object) == FALSE &&
+	if (GTK_IS_WIDGET (widget->object) && 
+	    GTK_WIDGET_TOPLEVEL (widget->object) == FALSE &&
 	    parent && fixed && !GWA_USE_PLACEHOLDERS (parent->adaptor) &&
 	    g_list_length (clipboard->selection) != 1) 
 	{
 		glade_util_ui_message (glade_app_get_window (), 
-				       GLADE_UI_INFO,
+				       GLADE_UI_INFO, NULL,
 				       _("Only one widget can be pasted at a "
 					 "time to this container"));
 		return;
@@ -1284,7 +1289,7 @@ glade_app_command_paste (GladePlaceholder *placeholder)
 	    glade_util_count_placeholders (parent) < placeholder_relations)
 	{
 		glade_util_ui_message (glade_app_get_window (), 
-				       GLADE_UI_INFO,
+				       GLADE_UI_INFO, NULL,
 				       _("Insufficient amount of placeholders in "
 					 "target container"));
 		return;
@@ -1315,22 +1320,10 @@ glade_app_command_delete (void)
 	for (list = glade_app_get_selection ();
 	     list && list->data; list = list->next)
 	{
-		widget  = glade_widget_get_from_gobject (GTK_WIDGET (list->data));
+		widget  = glade_widget_get_from_gobject (list->data);
 		widgets = g_list_prepend (widgets, widget);
-		
-		g_assert (widget);
-		if (widget->internal)
-		{
-			glade_util_ui_message
-				(glade_app_get_window(),
-				 GLADE_UI_WARN,
-				 _("You cannot delete a widget "
-				   "internal to a composite widget."));
-			failed = TRUE;
-			break;
-		}
 	}
-
+ 
 	if (failed == FALSE && widgets != NULL)
 	{
 		glade_command_delete (widgets);
@@ -1338,7 +1331,7 @@ glade_app_command_delete (void)
 	}
 	else if (widgets == NULL)
 		glade_util_ui_message (glade_app_get_window(),
-				       GLADE_UI_INFO,
+				       GLADE_UI_INFO, NULL,
 				       _("No widget selected."));
 
 	if (widgets) g_list_free (widgets);
@@ -1353,27 +1346,14 @@ void
 glade_app_command_delete_clipboard (void)
 {
 	GladeClipboard  *clipboard;
-	GladeWidget     *gwidget;
-	GList           *list;
 
 	clipboard = glade_app_get_clipboard ();
 
 	if (clipboard->selection == NULL)
-		glade_util_ui_message (glade_app_get_window (), GLADE_UI_INFO,
-				    _("No widget selected on the clipboard"));
-
-	for (list = clipboard->selection; list; list = list->next)
 	{
-		gwidget = list->data;
-		if (gwidget->internal)
-		{
-			glade_util_ui_message
-				(glade_app_get_window(),
-				 GLADE_UI_WARN,
-				 _("You cannot delete a widget "
-				   "internal to a composite widget."));
-			return;
-		}
+		glade_util_ui_message (glade_app_get_window (), GLADE_UI_INFO, NULL,
+				    _("No widget selected on the clipboard"));
+		return;
 	}
 
 	glade_command_delete (clipboard->selection);
@@ -1411,27 +1391,26 @@ glade_app_command_redo (void)
  * glade_app_set_accel_group:
  *
  * Sets @accel_group to app.
- * The acceleration group will be attached to every toplevel widget in this application.
+ * The acceleration group will made available for editor dialog windows
+ * from the plugin backend.
  */
 void
 glade_app_set_accel_group (GtkAccelGroup *accel_group)
 {
 	GladeApp *app;
-	GList *l;
-	GladeProject *project;
 	g_return_if_fail(GTK_IS_ACCEL_GROUP (accel_group));
 
 	app = glade_app_get ();
-
-	for (l = app->priv->projects; l; l = l->next)
-	{
-		project = l->data;
-		glade_project_set_accel_group (project, accel_group);
-	}
 	
 	app->priv->accel_group = accel_group;
 }
 
+GtkAccelGroup *
+glade_app_get_accel_group (void)
+{
+	return glade_app_get()->priv->accel_group;
+}
+
 static gboolean
 glade_app_undo_button_destroyed (GtkWidget *button, GladeApp *app)
 {
